@@ -12,7 +12,7 @@ a <- common.verbose(verbose)
   n.edges        <- nrow(locs)
   
   # convert the supplied adjacency matrix into a spam matrix, if required.
-  if(!is.symmetric.matrix(W)) stop("W is not symmetric.", call.=FALSE)
+  #if(!is.symmetric.matrix(W)) stop("W is not symmetric.", call.=FALSE)
   #if(class(W) == "matrix") W <- as.spam(W)
   #if(!class(W) %in% c("matrix", "spam")) stop("W must be an object with class \"matrix\" or \"spam\"", call.=FALSE)  
 
